pub struct PathBuilder { /* private fields */ }Expand description
A builder for paths.
Implementations
Sourceimpl PathBuilder
impl PathBuilder
Sourcepub fn line_to(self, x: f32, y: f32) -> Self
pub fn line_to(self, x: f32, y: f32) -> Self
Adds a line segment from the current point to x, y.
Sourcepub fn quad_to(self, cx: f32, cy: f32, x: f32, y: f32) -> Self
pub fn quad_to(self, cx: f32, cy: f32, x: f32, y: f32) -> Self
Adds a quadratic bezier from the current point to x, y,
using a control point of cx, cy.
Sourcepub fn cubic_to(
self,
x: f32,
y: f32,
cx1: f32,
cy1: f32,
cx2: f32,
cy2: f32,
) -> Self
pub fn cubic_to( self, x: f32, y: f32, cx1: f32, cy1: f32, cx2: f32, cy2: f32, ) -> Self
Adds a cubic bezier from the current point to x, y,
using control points cx1, cy1 and cx2, cy2.
Sourcepub fn arc(
self,
x: f32,
y: f32,
radius: f32,
start_angle: f32,
sweep_angle: f32,
) -> Self
pub fn arc( self, x: f32, y: f32, radius: f32, start_angle: f32, sweep_angle: f32, ) -> Self
Adds an arc approximated by quadratic beziers with center x, y
and radius r starting at start_angle and sweeping by sweep_angle.
For a positive sweep_angle the sweep is done clockwise, for a negative
sweep_angle the sweep is done counterclockwise.